@@ -135,7 +135,7 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
 
         testContext.forPdfOutput(d -> {
             assertPageTextContains(d.getPage(0), longFilename);
-            assertFooterHasText(d.getPage(16), longFilename.substring(0, 120) + " 17");
+            assertFooterHasText(d.getPage(16), longFilename.substring(0, 124) + " 17");
         });
     }
 
@@ -554,7 +554,7 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         MergeParameters parameters = new MergeParameters();
         parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
         parameters.addInput(new ImageMergeInput(customNonPdfInput("image/draft.png", "draft.png")));
-        parameters.addInput(new ImageMergeInput(customNonPdfInput("image/large.jpg", "large.png")));
+        parameters.addInput(new ImageMergeInput(customNonPdfInput("image/large.jpg", "large.jpg")));
         parameters.addInput(new ImageMergeInput(customNonPdfInput("image/draft.tiff", "draft.tiff")));
 
         parameters.setTableOfContentsPolicy(ToCPolicy.DOC_TITLES);
@@ -573,6 +573,51 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         });
     }
 
+    @Test
+    public void mergeImagesWithWrongFileExtension() throws IOException {
+        MergeParameters parameters = new MergeParameters();
+        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
+        parameters.addInput(new ImageMergeInput(customNonPdfInput("image/large.jpg", "large.png")));
+        parameters.addInput(new ImageMergeInput(customNonPdfInput("image/draft.png", "draft.jpeg")));
+
+        testContext.pdfOutputTo(parameters);
+        execute(parameters);
+
+        testContext.assertTaskCompleted();
+        testContext.assertPages(2);
+    }
+
+    @Test
+    public void mergeWithUnreadableImageThows() throws IOException {
+        MergeParameters parameters = new MergeParameters();
+        parameters.setLenient(false);
+        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
+        parameters.addInput(new ImageMergeInput(customNonPdfInput("image/draft.png", "draft.png")));
+        parameters.addInput(new ImageMergeInput(customNonPdfInput("image/corrupt.png", "corrupt.png")));
+
+        testContext.pdfOutputTo(parameters);
+        execute(parameters);
+
+        // TODO: friendlier error message
+        testContext.assertTaskFailed("org.sejda.model.exception.TaskIOException: An error occurred creating PDImageXObject from file source: corrupt.png");
+    }
+
+    @Test
+    public void mergeWithUnreadableImageWarning() throws IOException {
+        MergeParameters parameters = new MergeParameters();
+        parameters.setLenient(true);
+        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
+        parameters.addInput(new ImageMergeInput(customNonPdfInput("image/draft.png", "draft.png")));
+        parameters.addInput(new ImageMergeInput(customNonPdfInput("image/corrupt.png", "corrupt.png")));
+
+        testContext.pdfOutputTo(parameters);
+        execute(parameters);
+
+        testContext.assertTaskCompleted();
+        testContext.assertPages(1);
+        testContext.assertTaskWarning("Image corrupt.png was skipped, could not be processed");
+    }
+
     @Test
     public void mergeKeepingPageLabels() throws IOException {
         MergeParameters parameters = new MergeParameters();
@@ -602,6 +647,36 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         });
     }
 
+    @Test
+    public void mergeKeepingPageLabelsButDiscardingDecimalsStart() throws IOException {
+        MergeParameters parameters = new MergeParameters();
+        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
+        PDDocument doc1 = new DocBuilder().withPages(2)
+                .withPageLabelRange(0, "D", null, 2)
+                .get();
+        PDDocument doc2 = new DocBuilder().withPages(3)
+                .withPageLabelRange(0, "D", null, 7)
+                .get();
+
+        parameters.addInput(new PdfMergeInput(customInput(doc1, "doc1.pdf")));
+        parameters.addInput(new PdfMergeInput(customInput(doc2, "doc2.pdf")));
+        parameters.setCatalogPageLabelsPolicy(CatalogPageLabelsPolicy.RETAIN);
+        testContext.pdfOutputTo(parameters);
+        execute(parameters);
+
+        testContext.assertTaskCompleted();
+        testContext.assertPages(5).forEachPdfOutput(d -> {
+            try {
+                PDPageLabels mergedLabels = d.getDocumentCatalog().getPageLabels();
+                assertPageLabelIndexesAre(mergedLabels, 0, 2);
+                assertPageLabelRangeIs(mergedLabels, 0, new PDPageLabelRange("D", null, null));
+                assertPageLabelRangeIs(mergedLabels, 2, new PDPageLabelRange("D", null, null));
+            } catch (IOException e) {
+                throw new RuntimeException(e);
+            }
+        });
+    }
+
     @Test
     public void mergeDiscardingPageLabels() throws IOException {
         MergeParameters parameters = new MergeParameters();
